@@ -5,7 +5,7 @@
 #
 # SPDX-License-Identifier: MIT
 
-from typing import List
+from typing import Dict, List, Optional
 
 from tuxrun.devices import Device
 from tuxrun.exceptions import InvalidArgument
@@ -13,8 +13,13 @@ import tuxrun.templates as templates
 
 
 class FVPDevice(Device):
+    mandatory = ["mcp_fw", "mcp_romfw", "rootfs", "scp_fw", "scp_romfw", "uefi"]
+
     prompts: List[str] = []
+    auto_login: Dict[str, str] = {}
+    boot_timeout = 20
     support_tests = False
+    rootfs: Optional[str] = None
 
     def validate(
         self,
@@ -34,19 +39,27 @@ class FVPDevice(Device):
                 f"Invalid option(s) for fvp devices: {', '.join(invalid_args)}"
             )
 
-        mandatory = ["mcp_fw", "mcp_romfw", "rootfs", "scp_fw", "scp_romfw", "uefi"]
         args = locals()
-        missing_args = ["--" + k for k in mandatory if not args[k]]
+        missing_args = ["--" + k for k in self.mandatory if not args[k]]
         if len(missing_args) > 0:
             raise InvalidArgument(
                 f"Missing option(s) for fvp devices: {', '.join(missing_args)}"
             )
 
+        if tests and not self.support_tests:
+            raise InvalidArgument("Tests are not supported on this device")
+
+        if self.rootfs and rootfs:
+            raise InvalidArgument("Invalid option for this fvp device: --rootfs")
+
     def definition(self, **kwargs):
         # Options that can *not* be updated
         kwargs["prompts"] = self.prompts
+        kwargs["auto_login"] = self.auto_login
         kwargs["support_tests"] = self.support_tests
 
+        kwargs["rootfs"] = self.rootfs if self.rootfs else kwargs.get("rootfs")
+        kwargs["boot_timeout"] = self.boot_timeout
         # render the template
         return templates.jobs.get_template("fvp.yaml.jinja2").render(**kwargs)
 
@@ -94,3 +107,19 @@ class FVPMorelloOE(FVPDevice):
 
     prompts = ["root@morello-fvp:~# "]
     support_tests = True
+
+
+class FVPMorelloUbuntu(FVPDevice):
+    name = "fvp-morello-ubuntu"
+
+    mandatory = ["mcp_fw", "mcp_romfw", "scp_fw", "scp_romfw", "uefi"]
+
+    prompts = ["morello@morello-server:"]
+    auto_login = {
+        "login_prompt": "morello-server login:",
+        "username": "morello",
+        "password_prompt": "Password:",
+        "password": "morello",
+    }
+    boot_timeout = 60
+    rootfs = "https://storage.tuxboot.com/fvp-morello-ubuntu/ubuntu.satadisk.xz"
